pub enum AddressValidationError {
Empty,
MissingAt,
TooManyAtSigns,
EmptyLocalPart,
EmptyDomain,
InvalidLocalPart,
InvalidDomain,
InvalidDisplayName,
NonAscii,
}Expand description
Error returned when an email address primitive fails validation.
Variants
Empty
The supplied value was empty after trimming.
MissingAt
The address did not contain an at sign.
TooManyAtSigns
The address contained more than one at sign.
EmptyLocalPart
The local part was empty.
EmptyDomain
The domain part was empty.
InvalidLocalPart
The local part used syntax rejected by this crate’s conservative rules.
InvalidDomain
The domain part used syntax rejected by this crate’s conservative rules.
InvalidDisplayName
The display name used syntax rejected by this crate’s conservative rules.
NonAscii
The selected validation mode requires ASCII text.