pub struct EmailAddress { /* private fields */ }Expand description
Validated email address text split into local and domain parts.
Implementations
Sourceimpl EmailAddress
impl EmailAddress
Sourcepub fn new(
value: impl AsRef<str>,
) -> Result<EmailAddress, AddressValidationError>
pub fn new( value: impl AsRef<str>, ) -> Result<EmailAddress, AddressValidationError>
Creates an address using practical validation.
Sourcepub fn new_with_mode(
value: impl AsRef<str>,
mode: AddressValidationMode,
) -> Result<EmailAddress, AddressValidationError>
pub fn new_with_mode( value: impl AsRef<str>, mode: AddressValidationMode, ) -> Result<EmailAddress, AddressValidationError>
Creates an address using the requested validation mode.
Sourcepub fn from_parts(
local_part: impl AsRef<str>,
domain_part: impl AsRef<str>,
) -> Result<EmailAddress, AddressValidationError>
pub fn from_parts( local_part: impl AsRef<str>, domain_part: impl AsRef<str>, ) -> Result<EmailAddress, AddressValidationError>
Creates an address from already separated local and domain text.
Sourcepub fn from_parts_with_mode(
local_part: impl AsRef<str>,
domain_part: impl AsRef<str>,
mode: AddressValidationMode,
) -> Result<EmailAddress, AddressValidationError>
pub fn from_parts_with_mode( local_part: impl AsRef<str>, domain_part: impl AsRef<str>, mode: AddressValidationMode, ) -> Result<EmailAddress, AddressValidationError>
Creates an address from separated parts using the requested validation mode.
Sourcepub const fn local_part(&self) -> &LocalPart
pub const fn local_part(&self) -> &LocalPart
Returns the local part.
Sourcepub const fn domain_part(&self) -> &DomainPart
pub const fn domain_part(&self) -> &DomainPart
Returns the domain part.
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Returns an owned address string.