pub enum HeaderParseError {
EmptyName,
InvalidName,
InvalidValue,
MissingColon,
}Expand description
Error returned when header primitives fail validation or parsing.
Variants
EmptyName
The header name was empty.
InvalidName
The header name contained invalid token characters.
InvalidValue
The header value contained invalid control characters.
MissingColon
A header line did not contain a colon separator.