ThreadReference

Struct ThreadReference 

pub struct ThreadReference { /* private fields */ }
Simple thread reference path rooted at one message id.

Implementations

Source

impl ThreadReference

pub const fn new(root: MessageId) -> ThreadReference

Creates a thread reference from the root message id.

pub fn with_reply(self, reply: MessageId) -> ThreadReference

Adds a reply id and returns the updated thread reference.

pub const fn root(&self) -> &MessageId

Returns the root id.

pub fn replies(&self) -> &[MessageId]

Returns reply ids.

pub fn references(&self) -> References

Converts the thread reference into a References value.