pub struct ThreadReference { /* private fields */ }Expand description
Simple thread reference path rooted at one message id.
Implementations
Sourceimpl ThreadReference
impl ThreadReference
Sourcepub const fn new(root: MessageId) -> ThreadReference
pub const fn new(root: MessageId) -> ThreadReference
Creates a thread reference from the root message id.
Sourcepub fn with_reply(self, reply: MessageId) -> ThreadReference
pub fn with_reply(self, reply: MessageId) -> ThreadReference
Adds a reply id and returns the updated thread reference.
Sourcepub fn references(&self) -> References
pub fn references(&self) -> References
Converts the thread reference into a References value.